@@ -1,6 +1,6 @@
 package Data::SearchEngine::ElasticSearch;
 {
-  $Data::SearchEngine::ElasticSearch::VERSION = '0.14';
+  $Data::SearchEngine::ElasticSearch::VERSION = '0.15';
 }
 use Moose;
 
@@ -36,6 +36,13 @@ has '_es' => (
 );
 
 
+has 'filter_combiner' => (
+    is => 'rw',
+    isa => 'Str',
+    default => 'and'
+);
+
+
 has 'servers' => (
     is => 'ro',
     isa => 'Str|ArrayRef',
@@ -146,7 +153,7 @@ sub search {
         foreach my $filter ($query->filter_names) {
             push(@facet_cache, $query->get_filter($filter));
         }
-        $options->{filter}->{and} = \@facet_cache;
+        $options->{filter}->{$self->filter_combiner} = \@facet_cache;
     }
 
     if($query->has_facets) {
@@ -159,7 +166,7 @@ sub search {
 
         if($query->has_filters) {
             foreach my $f (keys %facets) {
-                $facets{$f}->{facet_filter}->{and} = \@facet_cache;
+                $facets{$f}->{facet_filter}->{$self->filter_combiner} = \@facet_cache;
             }
         }
 
@@ -265,7 +272,7 @@ Data::SearchEngine::ElasticSearch - ElasticSearch support for Data::SearchEngine
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -366,7 +373,8 @@ is expected that you will populate these values in the item thusly:
 
 =head2 Filters
 
-If you set multiple filters they will be ANDed together.
+If you set multiple filters they will be ANDed together.  If you want to change
+this behavior then you can change the C<filter_combiner> attribute to "or".
 
 =head2 Facets & Filters
 
@@ -375,6 +383,11 @@ C<facet_filter> so that the facets are limited similarly to the results.
 
 =head1 ATTRIBUTES
 
+=head2 filter_combiner
+
+Boolean used to combine filters. Should be either "and" or "or". Defaults to
+and.
+
 =head2 servers
 
 The servers to which we'll be connecting.
